@@ -386,11 +386,11 @@ def Heatmap_Survey_group_difference(df,comparison_col_name,comparison_order,choi
                     if pvalue <= significance_level:
                         #sns.scatterplot(x=[xtiks[ix] + (xtiks[1]-xtiks[0])/4],y=[ytiks[iy]],s=200,marker="***",color='black',ax=ax)
                         plt.text(x=xtiks[ix] + (xtiks[1]-xtiks[0])/4,y=ytiks[iy], s='***', fontsize=annotation_font_size)
-                    elif pvalue <= significance_level2:
+                    elif (pvalue <= significance_level2) and not single_star:
                         #sns.scatterplot(x=[xtiks[ix] + (xtiks[1]-xtiks[0])/4],y=[ytiks[iy]],s=200,marker="**",color='black',ax=ax)
                         plt.text(x=xtiks[ix] + (xtiks[1]-xtiks[0])/4,y=ytiks[iy], s='**', fontsize=annotation_font_size)
                         a=1
-                    elif pvalue <= significance_level3:
+                    elif (pvalue <= significance_level3) and not single_star:
                         #sns.scatterplot(x=[xtiks[ix] + (xtiks[1]-xtiks[0])/4],y=[ytiks[iy]],s=200,marker="*",color='black',ax=ax)
                         plt.text(x=xtiks[ix] + (xtiks[1]-xtiks[0])/4,y=ytiks[iy], s='*', fontsize=annotation_font_size)
 
